==> thx-api-0.1.tar.gz: thx-api-0.1/thx/api/exceptions.py <==
# -*- coding: utf-8 -*-
"""
Thux APIExceptions tree
+-- APIException (DRF)
    +-- ThuxAPIException
"""

import logging

from rest_framework.exceptions import APIException
from rest_framework.request import Request
from rest_framework.views import exception_handler
from django.utils.translations import ugettext_lazy as _


class BadRequest(APIException):
    status_code = 400
    default_detail = _('Bad request. Invalid parameter')
    default_code = _('Bad request. Invalid parameter')


# API EXCEPTION HANDLER
def thux_exception_handler(exc, context):
    # Call REST framework's default exception handler first,
    # to get the standard error response.
    response = exception_handler(exc, context)

    # Now add the HTTP status code to the response.
    if response is not None:
        response.data['status_code'] = response.status_code

    return response


# GENERIC CUSTOM API EXCEPTION
class ThuxAPIException(APIException):
    """
    To import:
        from web.drf import exceptions

    To raise:
        from rest_framework import status

        raise exceptions.ThuxAPIException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            request=request,
            msg='text of error',
        )
    """

    def __init__(self, status_code, request, msg=None, write_log=True):
        """
        :param status_code: HTTP status code
        :param request: view's request
        :param msg: error description
        :param write_log: if true a log is written in /var/log/django/thux-api_exceptions.log
        """
        self.logger = logging.getLogger('api_exceptions')
        self.status_code = status_code
        self.request = request
        if isinstance(self.request, Request):
            # if request is DRF-request then self.request = DJANGO-request
            self.request = self.request._request
        self.http_method = request.method

        super(ThuxAPIException, self).__init__(msg)
        if write_log:
            log_string = """{detail}\nurl: {url}\nmethod: {method}\nuser: {user}\ndata: {data}\n""".format(
                detail=self.detail,
                url=request.get_full_path(),
                method=getattr(request, 'method', ''),
                user=getattr(request, 'user', ''),
                data=getattr(request, 'data', ''),
            )
            self.logger.error(log_string)

    def get_repr_str(self):
        repr_str = u''
        if self.http_method:
            repr_str += '{} '.format(self.http_method.upper())
        repr_str += u'{} {}'.format(self.status_code, self.default_detail)
        return repr_str

    def __str__(self):
        return repr(self.get_repr_str())

    def __repr__(self):
        return repr(self.get_repr_str())

==> thx-api-0.2.1.tar.gz: thx-api-0.2.1/thx/api/exceptions.py <==
# -*- coding: utf-8 -*-
"""
Thux APIExceptions tree
+-- APIException (DRF)
    +-- ThuxAPIException
"""

import logging

from rest_framework.exceptions import APIException
from rest_framework.request import Request
from rest_framework.views import exception_handler
from django.utils.translation import ugettext_lazy as _


class BadRequest(APIException):
    status_code = 400
    default_detail = _('Bad request. Invalid parameter')
    default_code = _('Bad request. Invalid parameter')


# API EXCEPTION HANDLER
def thux_exception_handler(exc, context):
    # Call REST framework's default exception handler first,
    # to get the standard error response.
    response = exception_handler(exc, context)

    # Now add the HTTP status code to the response.
    if response is not None:
        response.data['status_code'] = response.status_code

    return response


# GENERIC CUSTOM API EXCEPTION
class ThuxAPIException(APIException):
    """
    To import:
        from web.drf import exceptions

    To raise:
        from rest_framework import status

        raise exceptions.ThuxAPIException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            request=request,
            msg='text of error',
        )
    """

    def __init__(self, status_code, request, msg=None, write_log=True):
        """
        :param status_code: HTTP status code
        :param request: view's request
        :param msg: error description
        :param write_log: if true a log is written in /var/log/django/thux-api_exceptions.log
        """
        self.logger = logging.getLogger('api_exceptions')
        self.status_code = status_code
        self.request = request
        if isinstance(self.request, Request):
            # if request is DRF-request then self.request = DJANGO-request
            self.request = self.request._request
        self.http_method = request.method

        super(ThuxAPIException, self).__init__(msg)
        if write_log:
            log_string = """{detail}\nurl: {url}\nmethod: {method}\nuser: {user}\ndata: {data}\n""".format(
                detail=self.detail,
                url=request.get_full_path(),
                method=getattr(request, 'method', ''),
                user=getattr(request, 'user', ''),
                data=getattr(request, 'data', ''),
            )
            self.logger.error(log_string)

    def get_repr_str(self):
        repr_str = u''
        if self.http_method:
            repr_str += '{} '.format(self.http_method.upper())
        repr_str += u'{} {}'.format(self.status_code, self.default_detail)
        return repr_str

    def __str__(self):
        return repr(self.get_repr_str())

    def __repr__(self):
        return repr(self.get_repr_str())
